ExitCode

Trait ExitCode 

pub trait ExitCode {
    // Required method
    fn code(self) -> i32;
}
Represents a value that can be used as the exit status of the process. See quick_main!.

Required Methods

fn code(self) -> i32

Returns the value to use as the exit status.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ExitCode for ()

Source

fn code(self) -> i32

Source

impl ExitCode for i32

Source

fn code(self) -> i32

Implementors